@@ -48,9 +48,10 @@ module WebMock
 
 
     def assign_options(options)
-      @body_pattern = BodyPattern.new(options[:body]) if options.has_key?(:body)
-      @headers_pattern = HeadersPattern.new(options[:headers]) if options.has_key?(:headers)
-      @uri_pattern.add_query_params(options[:query]) if options.has_key?(:query)
+      options = WebMock::Util::HashKeysStringifier.stringify_keys!(options, :deep => true)
+      @body_pattern = BodyPattern.new(options['body']) if options.has_key?('body')
+      @headers_pattern = HeadersPattern.new(options['headers']) if options.has_key?('headers')
+      @uri_pattern.add_query_params(options['query']) if options.has_key?('query')
     end
 
     def create_uri_pattern(uri)
@@ -102,7 +103,7 @@ module WebMock
       elsif rSpecHashIncludingMatcher?(query_params)
         WebMock::Matchers::HashIncludingMatcher.from_rspec_matcher(query_params)
       else
-        WebMock::Util::QueryMapper.query_to_values(query_params)
+        WebMock::Util::QueryMapper.query_to_values(query_params, :notation => Config.instance.query_values_notation)
       end
     end
 
@@ -116,7 +117,7 @@ module WebMock
   class URIRegexpPattern  < URIPattern
     def matches?(uri)
       WebMock::Util::URI.variations_of_uri_as_strings(uri).any? { |u| u.match(@pattern) } &&
-        (@query_params.nil? || @query_params == WebMock::Util::QueryMapper.query_to_values(uri.query))
+        (@query_params.nil? || @query_params == WebMock::Util::QueryMapper.query_to_values(uri.query, :notation => Config.instance.query_values_notation))
     end
 
     def to_s
@@ -155,7 +156,7 @@ module WebMock
       if @pattern.is_a?(Addressable::URI)
         if @query_params
           uri.omit(:query) === @pattern &&
-          (@query_params.nil? || @query_params == WebMock::Util::QueryMapper.query_to_values(uri.query))
+          (@query_params.nil? || @query_params == WebMock::Util::QueryMapper.query_to_values(uri.query, :notation => Config.instance.query_values_notation))
         else
           uri === @pattern
         end
@@ -167,8 +168,8 @@ module WebMock
     def add_query_params(query_params)
       super
       if @query_params.is_a?(Hash) || @query_params.is_a?(String)
-        query_hash = (WebMock::Util::QueryMapper.query_to_values(@pattern.query) || {}).merge(@query_params)
-        @pattern.query = WebMock::Util::QueryMapper.values_to_query(query_hash)
+        query_hash = (WebMock::Util::QueryMapper.query_to_values(@pattern.query, :notation => Config.instance.query_values_notation) || {}).merge(@query_params)
+        @pattern.query = WebMock::Util::QueryMapper.values_to_query(query_hash, :notation => WebMock::Config.instance.query_values_notation)
         @query_params = nil
       end
     end
@@ -232,7 +233,7 @@ module WebMock
       when :xml then
         Crack::XML.parse(body)
       else
-        WebMock::Util::QueryMapper.query_to_values(body)
+        WebMock::Util::QueryMapper.query_to_values(body, :notation => Config.instance.query_values_notation)
       end
     end
 
@@ -279,7 +280,7 @@ module WebMock
     end
 
     def normalize_hash(hash)
-      Hash[WebMock::Util::HashKeysStringifier.stringify_keys!(hash).sort]
+      Hash[WebMock::Util::HashKeysStringifier.stringify_keys!(hash, :deep => true).sort]
     end
 
   end
